==> mx-remastercc_19.9.tar.xz: mx-remastercc-19.9/translations/mx-remastercc_mr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="mr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MX Remastercc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>Persistence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;This tool allows you to rework an ISO while running Live. &lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Remaster&lt;/span&gt; allows you to change files, applications and settings with the goal of producing a new master copy for storage or distribution. &lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Persistence&lt;/span&gt; allows you to retain data, settings and installed programs when the machine gets switched off for personal use.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>Display help </source>
        <translation type="unfinished">मदत दाखवा</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Help</source>
        <translation type="unfinished">मदत</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Alt+H</source>
        <translation type="unfinished">Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>About this application</source>
        <translation type="unfinished">या अनुप्रयोगाबद्दल</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>About...</source>
        <translation type="unfinished">विषयी</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Alt+B</source>
        <translation type="unfinished">Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Quit application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Basic operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Remaster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Save root persistence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Optional operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Configure live persistence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="54"/>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>MX Remaster Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>About MX Remaster Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>Version: </source>
        <translation type="unfinished">आवृत्ती</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="98"/>
        <source>This program provides access to different remaster and persistence tools in MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished">कॉपीराइट (c) एमएक्स लिनक्स</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="101"/>
        <source>License</source>
        <translation type="unfinished">परवाना</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="102"/>
        <source>Changelog</source>
        <translation type="unfinished">बदल सूची</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Cancel</source>
        <translation type="unfinished">रद्द करा</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="119"/>
        <source>&amp;Close</source>
        <translation type="unfinished">बंद</translation>
    </message>
</context>
<context>
    <name>mxremastercc</name>
    <message>
        <source>Display help </source>
        <translation type="vanished">मदत दाखवा</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="vanished">मदत</translation>
    </message>
    <message>
        <source>Alt+H</source>
        <translation type="vanished">Alt+H</translation>
    </message>
    <message>
        <source>About this application</source>
        <translation type="vanished">या अनुप्रयोगाबद्दल</translation>
    </message>
    <message>
        <source>About...</source>
        <translation type="vanished">विषयी</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="vanished">Alt+B</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="vanished">Alt+N</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">आवृत्ती</translation>
    </message>
    <message>
        <source>Copyright (c) MX Linux</source>
        <translation type="vanished">कॉपीराइट (c) एमएक्स लिनक्स</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">परवाना</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">बदल सूची</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">रद्द करा</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">बंद</translation>
    </message>
</context>
</TS>

==> mx-remastercc_23.1.tar.xz: mx-remastercc-23.1/translations/mx-remastercc_mr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="mr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MX Remastercc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>Persistence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;This tool allows you to rework an ISO while running Live. &lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Remaster&lt;/span&gt; allows you to change files, applications and settings with the goal of producing a new master copy for storage or distribution. &lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Persistence&lt;/span&gt; allows you to retain data, settings and installed programs when the machine gets switched off for personal use.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>Display help </source>
        <translation>मदत दाखवा</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Help</source>
        <translation>मदत</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>About this application</source>
        <translation>या अनुप्रयोगाबद्दल</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>About...</source>
        <translation>विषयी</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Quit application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Basic operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Remaster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Save root persistence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Optional operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Configure live persistence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="50"/>
        <location filename="../mainwindow.cpp" line="99"/>
        <source>MX Remaster Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="78"/>
        <source>MX RemasterCC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="98"/>
        <source>About MX Remaster Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>Version: </source>
        <translation>आवृत्ती:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="101"/>
        <source>This program provides access to different remaster and persistence tools in MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Copyright (c) MX Linux</source>
        <translation>कॉपीराइट (c) एमएक्स लिनक्स</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>License</source>
        <translation>परवाना</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="105"/>
        <source>Changelog</source>
        <translation>बदल सूची</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="106"/>
        <source>Cancel</source>
        <translation>रद्द करा</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>&amp;Close</source>
        <translation>बंद</translation>
    </message>
</context>
</TS>
